@@ -3,11 +3,12 @@ package Math::BaseCalc;
 use strict;
 use Carp;
 use vars qw($VERSION);
-$VERSION = '1.013';
+$VERSION = '1.014';
 
 sub new {
   my ($pack, %opts) = @_;
   my $self = bless {}, $pack;
+  $self->{has_dash} = 0; 
   $self->digits($opts{digits});
   return $self;
 }
@@ -17,6 +18,7 @@ sub digits {
   if (@_) {
     # Set the value
 
+
     if (ref $_[0]) {
       $self->{digits} = [ @{ shift() } ];
     } else {
@@ -25,6 +27,7 @@ sub digits {
       croak "Unrecognized digit set '$name'" unless exists $digitsets{$name};
       $self->{digits} = $digitsets{$name};
     }
+    $self->{has_dash} = grep { $_ eq '-' } @{$self->{digits}};
 
     # Build the translation table back to numbers
     @{$self->{trans}}{@{$self->{digits}}} = 0..$#{$self->{digits}};
@@ -47,7 +50,7 @@ sub _digitsets {
 
 sub from_base {
   my $self = shift;
-  return -1*$self->from_base(substr($_[0],1)) if $_[0] =~ /^-/; # Handle negative numbers
+  return -1*$self->from_base(substr($_[0],1)) if !$self->{has_dash} && $_[0] =~ /^-/; # Handle negative numbers
   my $str = shift;
   my $dignum = @{$self->{digits}};
 
@@ -92,6 +95,10 @@ __END__
 
 Math::BaseCalc - Convert numbers between various bases
 
+=head1 VERSION
+
+version 1.014
+
 =head1 SYNOPSIS
 
   use Math::BaseCalc;
@@ -119,7 +126,7 @@ of first converting to a Perl number, then to the desired base for the
 result:
 
  $calc7  = new Math::BaseCalc(digits=>[0..6]);
- $calc36 = new Math::BaseCalc(digits=>[0..9,'a'..'z'];
+ $calc36 = new Math::BaseCalc(digits=>[0..9,'a'..'z']);
 
  $in_base_36 = $calc36->to_base( $calc7->from_base('3506') );
 
@@ -140,6 +147,9 @@ by either giving the digits in a list reference (in increasing order,
 with the 'zero' character first in the list) or by specifying the name
 of one of the predefined digit sets (see the digit() method below).
 
+If your digit set includes the character C<->, then a dash at the
+beginning of a number will no longer signify a negative number.
+
 =item * $calc->to_base(NUMBER)
 
 Converts a number to a string representing that number in the
@@ -198,4 +208,4 @@ it under the same terms as Perl itself.
 
 perl(1).
 
-=cut
+=cut
\ No newline at end of file
